@@ -18,11 +18,14 @@ Launch the Cylc hub for running the Cylc Web GUI.
 """
 
 import os
+from pathlib import Path
 
 from jupyterhub.app import main as hub_main
 
-from cylc.uiserver import __version__
-from cylc.uiserver.config import __file__ as config_file
+from cylc.uiserver import (
+    __version__,
+    __file__ as uis_pkg
+)
 
 
 def main(*args):
@@ -30,6 +33,7 @@ def main(*args):
         if arg.startswith('-f') or arg.startswith('--config'):
             break
     else:
+        config_file = Path(uis_pkg).parent / 'jupyterhub_config.py'
         args = (f'--config={config_file}',) + args
     # set an env var flag to help load the config
     os.environ['CYLC_HUB_VERSION'] = __version__
